import allure
from cerberus import Validator
from loguru import logger


class Validate:

    @allure.step('Проверка json-ответа на соответствие схеме')
    def validate_schema(self, test_json: dict, expected_json: dict):
        """
        Валидация json-ответа на соответствие схеме
        """
        v = Validator()
        if test_json != {}:
            if v.validate(test_json, expected_json):
                assert True
                logger.info('No errors in json')
            else:
                self.print_validate_error(v.errors)
                self.print_json_with_error(test_json)
                assert False
        else:
            assert False

    @allure.step('Ошибки валидации')
    def print_validate_error(self, errors: str):
        """
        Выводит поля с ошибками валидации json-ответа (отображается в аллюре)
        """
        logger.info(f'\nErrors: \n {errors}')

    @allure.step('JSON с ошибкой')
    def print_json_with_error(self, json_with_error: dict):
        """
        Выводит json с ошибкой (отображается в аллюре)
        :param json_with_error: dict
        :return:
        """
        logger.info(f'json с ошибкой: {json_with_error}')

    @allure.step('Проверка на соответствие')
    def assert_equal(self, expected_result, test_result):
        assert expected_result == test_result

    @allure.step('Проверка на НЕ соответствие')
    def assert_unequal(self, unexpected_result, test_result):
        assert unexpected_result != test_result



import allure
import requests
from dataclasses import dataclass

from jsvn_qa_utils_rest.src.data import Data
from jsvn_qa_utils_rest.src.validate import Validate
from loguru import logger
import time
from requests import Response
from typing import Dict, Any


@dataclass
class RestClient:

    base_url: str

    validate = Validate()
    data = Data()

    def get(self, url: str, headers: Dict[str, Any] = None, params: Dict[str, Any] = None) -> Response:
        start_time: float = time.time()
        r: Response = requests.get(url=url, headers=headers, params=params)
        time_now: float = time.time()
        request_time: float = time_now - start_time
        self.request_info('GET', url, r.status_code, time.ctime(time_now), request_time)
        return r

    def post(self, url: str, headers: Dict[str, Any] = None, json: Dict[str, Any] = None,
             data: Dict[str, Any] = None) -> Response:
        start: float = time.time()
        r: Response = requests.post(url=url, headers=headers, json=json, data=data)
        time_now: float = time.time()
        request_time: float = time_now - start
        self.request_info(method='POST', url=url, status_code=r.status_code,
                          time_now=time.ctime(time_now), request_time=request_time)
        return r

    def options(self, url: str, headers: Dict[str, Any] = None, data: Dict[str, Any] = None) -> Response:
        start_time: float = time.time()
        r: Response = requests.options(url=url, headers=headers, data=data)
        time_now: float = time.time()
        request_time: float = time_now - start_time
        self.request_info(method='OPTIONS', url=url, status_code=r.status_code,
                          time_now=time.ctime(time_now), request_time=request_time)
        return r

    def delete(self, url: str, headers: Dict[str, Any] = None, params: Dict[str, Any] = None) -> Response:
        start_time: float = time.time()
        r: Response = requests.delete(url=url, headers=headers, params=params)
        time_now: float = time.time()
        request_time: float = time_now - start_time
        self.request_info(method='DELETE', url=url, status_code=r.status_code,
                          time_now=time.ctime(time_now), request_time=request_time)
        return r

    @allure.step('Информация о запросе')
    def request_info(self, method: str, url: str, status_code: int, time_now: str, request_time=None) -> None:
        logger.info(f'{method} {url} {status_code} {time_now}, {request_time}')




from setuptools import setup

setup(
    name='jsvn_qa_utils_rest',
    version='1.0.2',
    packages=['jsvn_qa_utils_rest', 'jsvn_qa_utils_rest.src'],
    url='',
    license='',
    author='filipp.chachin',
    author_email='codejseven@gmail.com',
    description='test'
)



from random import randint, choice
from typing import List


class Data:
    # ---------------------- 1 lang ---------------------------------------------------------------------------------- #
    def symbol_feedback_message(self, ascii_symbols: bool = False) -> str:
        """
        генерация текста из символов
        :param ascii_symbols: использовать ASCII или нет, по умолчанию не используются
        :return: str
        """
        message_list: List[str] = []
        if not ascii_symbols:
            for _ in range(randint(10, 100)):
                symbol = self.random_symbol()
                message_list.append(symbol)
        else:
            for _ in range(randint(10, 100)):
                symbol = self.random_ascii_symbol()
                message_list.append(symbol)
        message_body: str = ''.join(message_list)
        return message_body

    @staticmethod
    def china_word(length: int) -> str:
        """
        текст из китайских иероглифов
        :param length: длина текста
        :return: str
        """
        letters: str = '是印版常的元均的分配世纪起就被作为此领式各样的版本'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}'
        return word

    @staticmethod
    def ru_word(length: int) -> str:
        """
        текст на кириллице
        :param length: длина текста
        :return: str
        """
        letters: str = 'ёйцукенгшщзхъфывапролджэячсмитьбюЁЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮ'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}'
        return word

    @staticmethod
    def en_word(length: int) -> str:
        """
        текст на латинице
        :param length: длина текста
        :return: str
        """
        letters: str = 'qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}'
        return word

    # --------------------------  one symbol ------------------------------------------------------------------------- #
    @staticmethod
    def random_ascii_symbol() -> str:
        """
        получение рандомного символа ASCII
        :return: str
        """
        symbols: List[str] = ['↔', '▲', '▼', '☻', '♣', '◘']
        symbol: str = choice(symbols)
        return symbol

    @staticmethod
    def random_symbol() -> str:
        """
        Получение рандомного символа
        :return: str
        """
        symbols: str = '~!@#$%^&*()`_+|=;:/?.>,<'
        list(symbols)
        return choice(symbols)

    # ------------------------- 2 lang --------------------------------------------------------------------------------#
    def symbol_in_ru_word(self, length: int) -> str:
        """
        вставляет в конец текста на кириллице рандомный символ
        :param length: длина текста
        :return: str
        """
        letters: str = 'ёйцукенгшщзхъфывапролджэячсмитьбюЁЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮ'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}{self.random_symbol()}'
        return word

    def ascii_symbol_in_ru_word(self, length: int) -> str:
        """
        вставляет в конце текста на кириллице ASCII-символ
        :param length: длина текста
        :return: str
        """
        letters: str = 'ёйцукенгшщзхъфывапролджэячсмитьбюЁЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮ'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}{self.random_ascii_symbol()}'
        return word

    @staticmethod
    def random_number_in_ru_word(length: int) -> str:
        """
        вставляет рандомную цифру в конец текста на кириллице
        :param length: длина текста
        :return: str
        """
        letters: str = 'ёйцукенгшщзхъфывапролджэячсмитьбюЁЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮ'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}{randint(1, 99)}'
        return word

    def random_symbol_in_en_word(self, length: int) -> str:
        """
        вставляет в конец текста на латинице рандомный символ
        :param length:  длина текста
        :return: str
        """
        letters: str = 'qwertyuiopasdfghjklzxcvbnmMNBVCXZASDFGHJKLPOIUYTREWQ'
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}{self.random_symbol()}'
        return word

    @staticmethod
    def en_in_ru_word(length: int) -> str:
        """
        вставляет в текст на кириллице одинаковую по написанию латинскую букву
        :param length: длина текста
        :return: str
        """
        letters: str = 'ёйцукенгшщзхъфывапролджэячсмитьбюЁЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮ'
        en_letters = 'yYHpPeEaAKcCBM'
        list(en_letters)
        list(letters)
        letters_list: List[str] = []
        for _ in range(length):
            letter: str = choice(letters)
            letters_list.append(letter)
        last_letter: str = ''.join(letters_list)
        word: str = f'{last_letter}{choice(en_letters)}'
        return word
